var schema = {
  /**
   * A model represents a single kind of object within the schema. There is a
   * 1:1 correspondence between Models and Java classes or JS type closures.
   */
  Model : {
    comment : "",
    enumValues : ["EnumValue"],
    name : "",
    properties : ["Property"]
  },
  /**
   * A specific Kind and parameterization thereof.
   */
  Type : {
    name : "",
    kind : "Kind",
    listElement : "Type",
    mapKey : "Type",
    mapValue : "Type"
  },
  /**
   * A Schema is the top-level object that encapsulates the normalized form of a
   * json-ddl schema.
   */
  Schema : {
    /**
     * General information about the schema itself.
     */
    comment : "",
    /**
     * A map of object models by simple name.
     */
    models : {"" : "Model"}
  },
  EnumValue : {
    comment : "",
    name : ""
  },
  /**
   * A property is a pair of a name and a type.
   */
  Property : {
    /**
     * This comment will be stored in this property.
     */
    comment : "",
    name : "",
    type : "Type"
  },
  /**
   * This is a simplified type system, representing only the types of data that
   * can be directly expressed in JSON.
   */
  Kind : [

    "BOOLEAN",
    "DDL",
    "DOUBLE",
    "ENUM",
    "EXTERNAL",
    "INTEGER",
    "LIST",
    "MAP",
    "STRING"
  ]
};
